"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from livepeer import utils
from livepeer._hooks import HookContext
from livepeer.models import components, errors, operations
from livepeer.types import BaseModel, OptionalNullable, UNSET
from typing import Any, Optional, Union, cast


class Generate(BaseSDK):
    r"""Operations related to AI generate api"""

    def text_to_image(
        self,
        *,
        request: Union[
            components.TextToImageParams, components.TextToImageParamsTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenTextToImageResponse:
        r"""Text To Image

        Generate images from text prompts.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.TextToImageParams)
        request = cast(components.TextToImageParams, request)

        req = self.build_request(
            method="POST",
            path="/api/beta/generate/text-to-image",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", components.TextToImageParams
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="genTextToImage",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenTextToImageResponse(
                image_response=utils.unmarshal_json(
                    http_res.text, Optional[components.ImageResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, "400", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenTextToImageResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenTextToImageResponseBody(data=data)
        if utils.match_response(http_res, "401", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenTextToImageGenerateResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenTextToImageGenerateResponseBody(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenTextToImageGenerateResponseResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenTextToImageGenerateResponseResponseBody(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenTextToImageGenerateResponse500ResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenTextToImageGenerateResponse500ResponseBody(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res.text, http_res
            )
        if utils.match_response(http_res, "default", "application/json"):
            return operations.GenTextToImageResponse(
                studio_api_error=utils.unmarshal_json(
                    http_res.text, Optional[errors.StudioAPIError]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )

        content_type = http_res.headers.get("Content-Type")
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res.text,
            http_res,
        )

    async def text_to_image_async(
        self,
        *,
        request: Union[
            components.TextToImageParams, components.TextToImageParamsTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenTextToImageResponse:
        r"""Text To Image

        Generate images from text prompts.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.TextToImageParams)
        request = cast(components.TextToImageParams, request)

        req = self.build_request_async(
            method="POST",
            path="/api/beta/generate/text-to-image",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", components.TextToImageParams
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="genTextToImage",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenTextToImageResponse(
                image_response=utils.unmarshal_json(
                    http_res.text, Optional[components.ImageResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, "400", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenTextToImageResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenTextToImageResponseBody(data=data)
        if utils.match_response(http_res, "401", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenTextToImageGenerateResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenTextToImageGenerateResponseBody(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenTextToImageGenerateResponseResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenTextToImageGenerateResponseResponseBody(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenTextToImageGenerateResponse500ResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenTextToImageGenerateResponse500ResponseBody(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res.text, http_res
            )
        if utils.match_response(http_res, "default", "application/json"):
            return operations.GenTextToImageResponse(
                studio_api_error=utils.unmarshal_json(
                    http_res.text, Optional[errors.StudioAPIError]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )

        content_type = http_res.headers.get("Content-Type")
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res.text,
            http_res,
        )

    def image_to_image(
        self,
        *,
        request: Union[
            components.BodyGenImageToImage, components.BodyGenImageToImageTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenImageToImageResponse:
        r"""Image To Image

        Apply image transformations to a provided image.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenImageToImage)
        request = cast(components.BodyGenImageToImage, request)

        req = self.build_request(
            method="POST",
            path="/api/beta/generate/image-to-image",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenImageToImage
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="genImageToImage",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenImageToImageResponse(
                image_response=utils.unmarshal_json(
                    http_res.text, Optional[components.ImageResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, "400", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenImageToImageResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenImageToImageResponseBody(data=data)
        if utils.match_response(http_res, "401", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenImageToImageGenerateResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenImageToImageGenerateResponseBody(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenImageToImageGenerateResponseResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenImageToImageGenerateResponseResponseBody(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(
                http_res.text,
                errors.GenImageToImageGenerateResponse500ResponseBodyUnion,
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenImageToImageGenerateResponse500ResponseBody(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res.text, http_res
            )
        if utils.match_response(http_res, "default", "application/json"):
            return operations.GenImageToImageResponse(
                studio_api_error=utils.unmarshal_json(
                    http_res.text, Optional[errors.StudioAPIError]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )

        content_type = http_res.headers.get("Content-Type")
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res.text,
            http_res,
        )

    async def image_to_image_async(
        self,
        *,
        request: Union[
            components.BodyGenImageToImage, components.BodyGenImageToImageTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenImageToImageResponse:
        r"""Image To Image

        Apply image transformations to a provided image.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenImageToImage)
        request = cast(components.BodyGenImageToImage, request)

        req = self.build_request_async(
            method="POST",
            path="/api/beta/generate/image-to-image",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenImageToImage
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="genImageToImage",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenImageToImageResponse(
                image_response=utils.unmarshal_json(
                    http_res.text, Optional[components.ImageResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, "400", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenImageToImageResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenImageToImageResponseBody(data=data)
        if utils.match_response(http_res, "401", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenImageToImageGenerateResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenImageToImageGenerateResponseBody(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenImageToImageGenerateResponseResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenImageToImageGenerateResponseResponseBody(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(
                http_res.text,
                errors.GenImageToImageGenerateResponse500ResponseBodyUnion,
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenImageToImageGenerateResponse500ResponseBody(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res.text, http_res
            )
        if utils.match_response(http_res, "default", "application/json"):
            return operations.GenImageToImageResponse(
                studio_api_error=utils.unmarshal_json(
                    http_res.text, Optional[errors.StudioAPIError]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )

        content_type = http_res.headers.get("Content-Type")
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res.text,
            http_res,
        )

    def image_to_video(
        self,
        *,
        request: Union[
            components.BodyGenImageToVideo, components.BodyGenImageToVideoTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenImageToVideoResponse:
        r"""Image To Video

        Generate a video from a provided image.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenImageToVideo)
        request = cast(components.BodyGenImageToVideo, request)

        req = self.build_request(
            method="POST",
            path="/api/beta/generate/image-to-video",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenImageToVideo
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="genImageToVideo",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenImageToVideoResponse(
                video_response=utils.unmarshal_json(
                    http_res.text, Optional[components.VideoResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, "400", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenImageToVideoResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenImageToVideoResponseBody(data=data)
        if utils.match_response(http_res, "401", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenImageToVideoGenerateResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenImageToVideoGenerateResponseBody(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenImageToVideoGenerateResponseResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenImageToVideoGenerateResponseResponseBody(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(
                http_res.text,
                errors.GenImageToVideoGenerateResponse500ResponseBodyUnion,
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenImageToVideoGenerateResponse500ResponseBody(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res.text, http_res
            )
        if utils.match_response(http_res, "default", "application/json"):
            return operations.GenImageToVideoResponse(
                studio_api_error=utils.unmarshal_json(
                    http_res.text, Optional[errors.StudioAPIError]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )

        content_type = http_res.headers.get("Content-Type")
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res.text,
            http_res,
        )

    async def image_to_video_async(
        self,
        *,
        request: Union[
            components.BodyGenImageToVideo, components.BodyGenImageToVideoTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenImageToVideoResponse:
        r"""Image To Video

        Generate a video from a provided image.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenImageToVideo)
        request = cast(components.BodyGenImageToVideo, request)

        req = self.build_request_async(
            method="POST",
            path="/api/beta/generate/image-to-video",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenImageToVideo
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="genImageToVideo",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenImageToVideoResponse(
                video_response=utils.unmarshal_json(
                    http_res.text, Optional[components.VideoResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, "400", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenImageToVideoResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenImageToVideoResponseBody(data=data)
        if utils.match_response(http_res, "401", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenImageToVideoGenerateResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenImageToVideoGenerateResponseBody(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenImageToVideoGenerateResponseResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenImageToVideoGenerateResponseResponseBody(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(
                http_res.text,
                errors.GenImageToVideoGenerateResponse500ResponseBodyUnion,
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenImageToVideoGenerateResponse500ResponseBody(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res.text, http_res
            )
        if utils.match_response(http_res, "default", "application/json"):
            return operations.GenImageToVideoResponse(
                studio_api_error=utils.unmarshal_json(
                    http_res.text, Optional[errors.StudioAPIError]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )

        content_type = http_res.headers.get("Content-Type")
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res.text,
            http_res,
        )

    def upscale(
        self,
        *,
        request: Union[components.BodyGenUpscale, components.BodyGenUpscaleTypedDict],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenUpscaleResponse:
        r"""Upscale

        Upscale an image by increasing its resolution.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenUpscale)
        request = cast(components.BodyGenUpscale, request)

        req = self.build_request(
            method="POST",
            path="/api/beta/generate/upscale",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenUpscale
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="genUpscale",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenUpscaleResponse(
                image_response=utils.unmarshal_json(
                    http_res.text, Optional[components.ImageResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, "400", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenUpscaleResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenUpscaleResponseBody(data=data)
        if utils.match_response(http_res, "401", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenUpscaleGenerateResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenUpscaleGenerateResponseBody(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenUpscaleGenerateResponseResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenUpscaleGenerateResponseResponseBody(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenUpscaleGenerateResponse500ResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenUpscaleGenerateResponse500ResponseBody(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res.text, http_res
            )
        if utils.match_response(http_res, "default", "application/json"):
            return operations.GenUpscaleResponse(
                studio_api_error=utils.unmarshal_json(
                    http_res.text, Optional[errors.StudioAPIError]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )

        content_type = http_res.headers.get("Content-Type")
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res.text,
            http_res,
        )

    async def upscale_async(
        self,
        *,
        request: Union[components.BodyGenUpscale, components.BodyGenUpscaleTypedDict],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenUpscaleResponse:
        r"""Upscale

        Upscale an image by increasing its resolution.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenUpscale)
        request = cast(components.BodyGenUpscale, request)

        req = self.build_request_async(
            method="POST",
            path="/api/beta/generate/upscale",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenUpscale
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="genUpscale",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenUpscaleResponse(
                image_response=utils.unmarshal_json(
                    http_res.text, Optional[components.ImageResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, "400", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenUpscaleResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenUpscaleResponseBody(data=data)
        if utils.match_response(http_res, "401", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenUpscaleGenerateResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenUpscaleGenerateResponseBody(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenUpscaleGenerateResponseResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenUpscaleGenerateResponseResponseBody(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenUpscaleGenerateResponse500ResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenUpscaleGenerateResponse500ResponseBody(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res.text, http_res
            )
        if utils.match_response(http_res, "default", "application/json"):
            return operations.GenUpscaleResponse(
                studio_api_error=utils.unmarshal_json(
                    http_res.text, Optional[errors.StudioAPIError]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )

        content_type = http_res.headers.get("Content-Type")
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res.text,
            http_res,
        )

    def audio_to_text(
        self,
        *,
        request: Union[
            components.BodyGenAudioToText, components.BodyGenAudioToTextTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenAudioToTextResponse:
        r"""Audio To Text

        Transcribe audio files to text.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenAudioToText)
        request = cast(components.BodyGenAudioToText, request)

        req = self.build_request(
            method="POST",
            path="/api/beta/generate/audio-to-text",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenAudioToText
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="genAudioToText",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "413", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenAudioToTextResponse(
                text_response=utils.unmarshal_json(
                    http_res.text, Optional[components.TextResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, "400", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenAudioToTextResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenAudioToTextResponseBody(data=data)
        if utils.match_response(http_res, "401", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenAudioToTextGenerateResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenAudioToTextGenerateResponseBody(data=data)
        if utils.match_response(http_res, "413", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenAudioToTextGenerateResponseResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenAudioToTextGenerateResponseResponseBody(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenAudioToTextGenerateResponse422ResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenAudioToTextGenerateResponse422ResponseBody(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenAudioToTextGenerateResponse500ResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenAudioToTextGenerateResponse500ResponseBody(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res.text, http_res
            )
        if utils.match_response(http_res, "default", "application/json"):
            return operations.GenAudioToTextResponse(
                studio_api_error=utils.unmarshal_json(
                    http_res.text, Optional[errors.StudioAPIError]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )

        content_type = http_res.headers.get("Content-Type")
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res.text,
            http_res,
        )

    async def audio_to_text_async(
        self,
        *,
        request: Union[
            components.BodyGenAudioToText, components.BodyGenAudioToTextTypedDict
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenAudioToTextResponse:
        r"""Audio To Text

        Transcribe audio files to text.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenAudioToText)
        request = cast(components.BodyGenAudioToText, request)

        req = self.build_request_async(
            method="POST",
            path="/api/beta/generate/audio-to-text",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenAudioToText
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="genAudioToText",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "413", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenAudioToTextResponse(
                text_response=utils.unmarshal_json(
                    http_res.text, Optional[components.TextResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, "400", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenAudioToTextResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenAudioToTextResponseBody(data=data)
        if utils.match_response(http_res, "401", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenAudioToTextGenerateResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenAudioToTextGenerateResponseBody(data=data)
        if utils.match_response(http_res, "413", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenAudioToTextGenerateResponseResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenAudioToTextGenerateResponseResponseBody(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenAudioToTextGenerateResponse422ResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenAudioToTextGenerateResponse422ResponseBody(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenAudioToTextGenerateResponse500ResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenAudioToTextGenerateResponse500ResponseBody(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res.text, http_res
            )
        if utils.match_response(http_res, "default", "application/json"):
            return operations.GenAudioToTextResponse(
                studio_api_error=utils.unmarshal_json(
                    http_res.text, Optional[errors.StudioAPIError]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )

        content_type = http_res.headers.get("Content-Type")
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res.text,
            http_res,
        )

    def segment_anything2(
        self,
        *,
        request: Union[
            components.BodyGenSegmentAnything2,
            components.BodyGenSegmentAnything2TypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenSegmentAnything2Response:
        r"""Segment Anything 2

        Segment objects in an image.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenSegmentAnything2)
        request = cast(components.BodyGenSegmentAnything2, request)

        req = self.build_request(
            method="POST",
            path="/api/beta/generate/segment-anything-2",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenSegmentAnything2
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="genSegmentAnything2",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenSegmentAnything2Response(
                masks_response=utils.unmarshal_json(
                    http_res.text, Optional[components.MasksResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, "400", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenSegmentAnything2ResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenSegmentAnything2ResponseBody(data=data)
        if utils.match_response(http_res, "401", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenSegmentAnything2GenerateResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenSegmentAnything2GenerateResponseBody(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(
                http_res.text,
                errors.GenSegmentAnything2GenerateResponseResponseBodyUnion,
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenSegmentAnything2GenerateResponseResponseBody(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(
                http_res.text,
                errors.GenSegmentAnything2GenerateResponse500ResponseBodyUnion,
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenSegmentAnything2GenerateResponse500ResponseBody(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res.text, http_res
            )
        if utils.match_response(http_res, "default", "application/json"):
            return operations.GenSegmentAnything2Response(
                studio_api_error=utils.unmarshal_json(
                    http_res.text, Optional[errors.StudioAPIError]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )

        content_type = http_res.headers.get("Content-Type")
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res.text,
            http_res,
        )

    async def segment_anything2_async(
        self,
        *,
        request: Union[
            components.BodyGenSegmentAnything2,
            components.BodyGenSegmentAnything2TypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> operations.GenSegmentAnything2Response:
        r"""Segment Anything 2

        Segment objects in an image.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, components.BodyGenSegmentAnything2)
        request = cast(components.BodyGenSegmentAnything2, request)

        req = self.build_request_async(
            method="POST",
            path="/api/beta/generate/segment-anything-2",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "multipart", components.BodyGenSegmentAnything2
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="genSegmentAnything2",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.GenSegmentAnything2Response(
                masks_response=utils.unmarshal_json(
                    http_res.text, Optional[components.MasksResponse]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, "400", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenSegmentAnything2ResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenSegmentAnything2ResponseBody(data=data)
        if utils.match_response(http_res, "401", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, errors.GenSegmentAnything2GenerateResponseBodyUnion
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenSegmentAnything2GenerateResponseBody(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(
                http_res.text,
                errors.GenSegmentAnything2GenerateResponseResponseBodyUnion,
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenSegmentAnything2GenerateResponseResponseBody(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(
                http_res.text,
                errors.GenSegmentAnything2GenerateResponse500ResponseBodyUnion,
            )
            data.http_meta = components.HTTPMetadata(request=req, response=http_res)
            raise errors.GenSegmentAnything2GenerateResponse500ResponseBody(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            raise errors.SDKError(
                "API error occurred", http_res.status_code, http_res.text, http_res
            )
        if utils.match_response(http_res, "default", "application/json"):
            return operations.GenSegmentAnything2Response(
                studio_api_error=utils.unmarshal_json(
                    http_res.text, Optional[errors.StudioAPIError]
                ),
                http_meta=components.HTTPMetadata(request=req, response=http_res),
            )

        content_type = http_res.headers.get("Content-Type")
        raise errors.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res.text,
            http_res,
        )
